netapp_ontap.models.entitlement API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.entitlement`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class EntitlementSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Entitlement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: str GET`

    Entitlement action to be taken to mitigate the risk

    Valid choices:

    - acquire_license
    - adjust_capacity
    - verify_entitlement
    - verify_system_health
    - none
  `risk: str GET`

    Entitlement risk of the package

    Valid choices:

    - high
    - medium
    - low
    - unlicensed
    - unknown